<footer>
    <div class="container">
        <div class="row">
            <div class="col-sm-4">
                <p>GeoKey {{ GEOKEY_VERSION }}</p>
                <p>Created by <a href="http://www.ucl.ac.uk/excites" target="_blank" title="ExCiteS homepage" class="light">ExCiteS research group</a>
            </div>

            <div class="col-sm-4">
                <p><a href="http://geokey.org.uk/help/" target="_blank" title="GeoKey Help" class="light">Help</a></p>
                <p><a href="http://geokey.org.uk/docs/web-api.html" target="_blank" title="GeoKey API documentation" class="light">API documentation</a></p>
            </div>

            <div class="col-sm-4">
                <p><a href="https://twitter.com/geokey_project" target="_blank" title="GeoKey Twitter account" class="light">Follow GeoKey on Twitter</a></p>
                <p><a href="https://github.com/ExCiteS/geokey/" target="_blank" title="GeoKey GitHub source code" class="light">Contribute on GitHub</a></p>
            </div>
        </div>
    </div>
</footer>
