{% extends 'base.html' %}

{% block title %} | Other projects{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Other projects</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    {% for project in projects %}
        <div class="row">
            <div class="col-sm-8">
                <h3>{{ project.name }}</h3>
                <p>{{ project.role }}</p>
            </div>

            <div class="col-sm-4 contributions">
                <span class="number">{{ project.contributions }}</span>
                contributions
            </div>
        </div>
    {% empty %}
        <div class="row">
            <div class="col-sm-12">
                <p>No projects found.</p>
            </div>
        </div>
    {% endfor %}
</div>
{% endblock %}
