{{#each lookupvalues}}
    <li class="list-group-item">
        <div class="value-display">
            <span class="value-label">{{name}}</span>

            <span class="btn-group">
                {{#unless locked}}
                    <button type="button" class="btn btn-default btn-xs edit-value">
                        <span class="text-primary">edit value</span>
                    </button>
                {{/unless}}

                <button type="button" class="btn btn-default btn-xs edit-symbol">
                    {{#if locked}}
                        <span class="text-primary btn-value-edit-symbol">show symbol</span>
                    {{else if symbol}}
                        <span class="text-primary btn-value-edit-symbol">edit symbol</span>
                    {{else}}
                        <span class="text-success btn-value-edit-symbol">add symbol</span>
                    {{/if}}
                </button>

                {{#unless locked}}
                    <button type="button" class="btn btn-default btn-xs delete-value" value="{{id}}">
                        <span class="text-danger">delete</span>
                    </button>
                {{/unless}}
            </span>
        </div>

        {{#unless locked}}
            <div class="value-edit hidden">
                <div class="form-group">
                    <label class="control-label">Value</label>
                    <input type="text" name="value" class="form-control" value="{{name}}" />
                </div>

                 <div class="form-group">
                    <button type="button" class="btn btn-primary save-value" value="{{id}}" data-loading-text="Saving...">Save</button>
                    <button type="button" class="btn btn-default cancel-value">Cancel</button>
                </div>
            </div>
        {{/unless}}

        <div class="symbol-edit hidden">
            <input type="hidden" name="clear-symbol" id="{{id}}-clear" value="false">

            <div class="form-group">
                <label class="control-label">Symbol</label>
                <input type="file" name="symbol" data-target="{{id}}" {{#if symbol}}data-preview="{{symbol}}"{{/if}} {{#if locked}}disabled{{/if}} />
            </div>

            {{#unless locked}}
                <div class="form-group">
                    <button type="button" class="btn btn-primary save-symbol" value="{{id}}" data-loading-text="Saving...">Save</button>
                    <button type="button" class="btn btn-default cancel-symbol">Cancel</button>
                </div>
            {{/unless}}
        </div>
    </li>
{{/each}}
