{% extends 'base.html' %}
{% block title %} | Verify email address{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Verify email address</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="alert alert-info">
        <p>We've emailed you instructions for verifying your email address. You should be receiving them shortly. Follow the link provided to finalise the sign up process. If you don't receive an email, please make sure you've checked your spam folder.</p>
    </div>
</div>
{% endblock %}
