{% extends 'base.html' %}
{% block title %} | Authentication cancelled{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Authentication cancelled</h1>
    </div>
</div>

<div class="container">
    <div class="row">
        <div class="col-sm-10 col-sm-offset-1 col-md-8 col-md-offset-2">
            <div class="alert alert-danger">You decided to cancel the authentication process using one of your existing accounts. If this was a mistake, please proceed to <a href="{% url 'account_login' %}">sign in</a> page.</div>
        </div>
    </div>
</div>
{% endblock %}
