{% extends 'base.html' %}
{% block title %} | Reset password{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Reset password</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="row">
        <div class="col-sm-8 col-sm-offset-2 col-md-6 col-md-offset-3">
            <form action="{% url 'account_reset_password' %}" method="POST" novalidate>
                {% csrf_token %}

                <div class="form-group {% if form.email.errors %}has-error{% endif %}">
                    <label for="email">Please enter your email address to receive reset instructions</label>
                    <input type="email" class="form-control input-lg" id="email" name="email" value="{{ form.data.email }}" required />
                    {% if form.email.errors %}<span class="help-block">{{ form.email.errors|striptags }}</span>{% endif %}
                </div>

                <div class="form-group">
                    <button type="submit" class="btn btn-lg btn-primary">Reset password</button>
                </div>
            </form>
        </div>
    </div>
</div>
{% endblock %}

{% block libraries %}
<script src="/static/js/admin.ui.forms.validate.js"></script>
{% endblock %}
