<p>
    <span class="label label-primary">{{ private_label }}</span>
    {% if inactive %}<span class="label label-warning">Archived</span>{% endif %}
</p>

<p class="meta">Created by {{ creator }} on {{ created_at }}</p>
