{% extends 'base.html' %}

{% block title %} | Superuser tools - Platform settings{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Superuser tools</h1>
        {% include 'superusertools/navigation.html' %}
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="row">
        <div class="col-sm-10 col-sm-offset-1 col-md-8 col-md-offset-2">
            <form method="POST" action="{% url 'admin:superusertools_platform_settings' %}" novalidate>
                {% csrf_token %}

                <h2 class="header">General settings</h2>

                <div class="form-group">
                    <label for="name">Name</label>
                    <input type="text" id="name" class="form-control input-lg" name="name" maxlength="50" value="{{ site.name }}" required />
                </div>

                <div class="form-group">
                    <label for="domain">Domain</label>
                    <input type="url" id="domain" class="form-control input-lg" name="domain" maxlength="100" value="{{ site.domain }}" required />
                </div>

                <div class="form-group">
                    <button type="submit" class="btn btn-primary">Save</button>
                    <button type="reset" class="btn btn-link">Reset</button>
                </div>
            </form>
        </div>
    </div>
</div>
{% endblock %}

{% block libraries %}
<script src="/static/js/admin.ui.forms.validate.js"></script>
{% endblock %}
