{% extends 'base.html' %}
{% block title %} | Set new password successful{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Set new password successful</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="alert alert-success">
        <p>Your new password has been set. You may go ahead and <a href="{% url 'account_login' %}">sign in</a> now.</p>
    </div>
</div>
{% endblock %}
