{% extends 'base.html' %}
{% block title %} | Reset password successful{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Reset password successful</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="alert alert-success">
        <p>We've emailed you instructions for resetting your password. You should be receiving them shortly. If you don't receive an email, please make sure you've entered the address you registered with, and check your spam folder.</p>
    </div>
</div>
{% endblock %}
