<ul class="nav nav-tabs header-nav">
    <li role="presentation" class="{% if request.resolver_match.url_name == 'project_overview' %}active{% endif %}">
        <a href="{% url 'admin:project_overview' project.id %}">Overview</a>
    </li>

    <li role="presentation" class="{% if 'category' in request.resolver_match.url_name %}active{% endif %}">
        <a href="{% url 'admin:category_list' project.id %}">Categories</a>
    </li>

    <li role="presentation" class="{% if 'usergroup' in request.resolver_match.url_name or request.resolver_match.url_name == 'admins_overview' %}active{% endif %}">
        <a href="{% url 'admin:usergroup_list' project.id %}">User groups</a>
    </li>

    <li role="presentation" class="{% if 'subset' in request.resolver_match.url_name %}active{% endif %}">
        <a href="{% url 'admin:subset_list' project.id %}">Subsets</a>
    </li>

    <li role="presentation" class="{% if request.resolver_match.url_name == 'project_geographicextent' %}active{% endif %}">
        <a href="{% url 'admin:project_geographicextent' project.id %}">Geographic extent</a>
    </li>

    <li role="presentation" class="{% if request.resolver_match.url_name == 'project_settings' %}active{% endif %}">
        <a href="{% url 'admin:project_settings' project.id %}">Settings</a>
    </li>
</ul>
