{% if DEBUG %}
    <div class="alert alert-warning">
        <p>The administrator has enabled DEBUG mode for this platform. This very likely means that the platform is run as a test environment and things may break. Please get in touch with the administrator if you constantly experience problems.</p>
    </div>
{% endif %}

{% for message in messages %}
    <div class="alert alert-{{ message.tags }} alert-dismissible">
        <button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
        {{ message|linebreaks }}
    </div>
{% endfor %}
