{% extends 'base.html' %}
{% block title %} | Confirm email address{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Confirm email address</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="alert alert-danger">
        <p>The email confirmation link was invalid, possibly because it has already expired. Please request a <a href="{% url 'account_email' %}">new email confirmation</a>.</p>
    </div>
</div>
{% endblock %}
