{% extends 'base.html' %}
{% block title %} | Inactive account{% endblock %}

{% block main %}
<div class="page-header">
    <div class="container">
        <h1>Inactive account</h1>
    </div>
</div>

<div class="container">
    {% include 'snippets/messages.html' %}

    <div class="alert alert-danger">
        <p>Your account is inactive; likely because you have not confirmed your email address yet. We've emailed you new instructions for verifying your email address. Follow the link provided to activate your account. If you don't receive an email, please make sure you've checked your spam folder.</p>
    </div>
</div>
{% endblock %}
