<div class="panel panel-default">
    <div class="panel-heading">
        <h6 class="item-info">Subset</h6>

        <h3>
            {% if project.islocked %}<span class="glyphicon glyphicon-lock" aria-hidden="true"></span>{% endif %}
            {{ subset.name }}
        </h3>
    </div>

    <div class="list-group">
        <a href="{% url 'admin:subset_data' subset.project.id subset.id %}" class="list-group-item {% if request.resolver_match.url_name == 'subset_data' %}active{% endif %}">Data</a>
        <a href="{% url 'admin:subset_settings' subset.project.id subset.id %}" class="list-group-item {% if request.resolver_match.url_name == 'subset_settings' %}active{% endif %}">Settings</a>
    </div>
</div>
